==> HTML-Menu-TreeView-0.7.0.tar.gz: HTML-Menu-TreeView-0.7.0/httpdocs/style/Crystal/32/html-menu-treeview/preload.js <==
folderClosed = new Image(32,32);
folderClosed.src='/style/Crystal/32/html-menu-treeview/folderClosed.gif';
plusNode = new Image(32,32);
plusNode.src='/style/Crystal/32/html-menu-treeview/plusNode.gif';
lastPlusNode = new Image(32,32);
lastPlusNode.src='/style/Crystal/32/html-menu-treeview/lastPlusNode.gif';
clasicPlusNode = new Image(32,32);
clasicPlusNode.src='/style/Crystal/32/html-menu-treeview/clasicPlusNode.gif';
clasicLastPlusNode = new Image(32,32);
clasicLastPlusNode.src='/style/Crystal/32/html-menu-treeview/clasicLastPlusNode.gif';
folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(32,32);
folderGray.src='/style/Crystal/32/html-menu-treeview/folderGray.gif';
folderGreen = new Image(32,32);
folderGreen.src='/style/Crystal/32/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(32,32);
folderViolet.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(32,32);
folderYellowClosed.src='/style/Crystal/32/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(32,32);
folderOrangeClosed.src='/style/Crystal/32/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(32,32);
folderHtmlClosed.src='/style/Crystal/32/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(32,32);
folderFavoriteClosed.src='/style/Crystal/32/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(32,32);
folderTextClosed.src='/style/Crystal/32/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(32,32);
folderLockedClosed.src='/style/Crystal/32/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(32,32);
folderCrystalClosed.src='/style/Crystal/32/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(32,32);
folderVideoClosed.src='/style/Crystal/32/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(32,32);
folderPrintClosed.src='/style/Crystal/32/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(32,32);
folderImageClosed.src='/style/Crystal/32/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(32,32);
folderSoundClosed.src='/style/Crystal/32/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(32,32);
folderImportantClosed.src='/style/Crystal/32/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(32,32);
folderTarClosed.src='/style/Crystal/32/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.8.3.tar.gz: HTML-Menu-TreeView-0.8.3/httpdocs/style/Crystal/32/html-menu-treeview/preload.js <==
var folderClosed = new Image(32,32);
folderClosed.src='/style/Crystal/32/html-menu-treeview/folderClosed.gif';
var plusNode = new Image(32,32);
plusNode.src='/style/Crystal/32/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(32,32);
lastPlusNode.src='/style/Crystal/32/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(32,32);
clasicPlusNode.src='/style/Crystal/32/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(32,32);
clasicLastPlusNode.src='/style/Crystal/32/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
var folderGray = new Image(32,32);
folderGray.src='/style/Crystal/32/html-menu-treeview/folderGray.gif';
var folderGreen = new Image(32,32);
folderGreen.src='/style/Crystal/32/html-menu-treeview/folderGreen.gif';
var folderViolet = new Image(32,32);
folderViolet.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
var folderYellowClosed = new Image(32,32);
folderYellowClosed.src='/style/Crystal/32/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed = new Image(32,32);
folderOrangeClosed.src='/style/Crystal/32/html-menu-treeview/folderOrangeClosed.gif';
var folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
var folderHtmlClosed = new Image(32,32);
folderHtmlClosed.src='/style/Crystal/32/html-menu-treeview/folderHtmlClosed.gif';
var folderFavoriteClosed = new Image(32,32);
folderFavoriteClosed.src='/style/Crystal/32/html-menu-treeview/folderFavoriteClosed.gif';
var folderTextClosed = new Image(32,32);
folderTextClosed.src='/style/Crystal/32/html-menu-treeview/folderTextClosed.gif';
var folderLockedClosed = new Image(32,32);
folderLockedClosed.src='/style/Crystal/32/html-menu-treeview/folderLockedClosed.gif';
var folderCrystalClosed = new Image(32,32);
folderCrystalClosed.src='/style/Crystal/32/html-menu-treeview/folderCrystalClosed.gif';
var folderVideoClosed = new Image(32,32);
folderVideoClosed.src='/style/Crystal/32/html-menu-treeview/folderVideoClosed.gif';
var folderPrintClosed = new Image(32,32);
folderPrintClosed.src='/style/Crystal/32/html-menu-treeview/folderPrintClosed.gif';
var folderImageClosed = new Image(32,32);
folderImageClosed.src='/style/Crystal/32/html-menu-treeview/folderImageClosed.gif';
var folderSoundClosed = new Image(32,32);
folderSoundClosed.src='/style/Crystal/32/html-menu-treeview/folderSoundClosed.gif';
var folderImportantClosed = new Image(32,32);
folderImportantClosed.src='/style/Crystal/32/html-menu-treeview/folderImportantClosed.gif';
var folderTarClosed = new Image(32,32);
folderTarClosed.src='/style/Crystal/32/html-menu-treeview/folderTarClosed.gif';
